#!/usr/bin/env python
# coding: utf-8

from datetime import datetime

import matplotlib.pyplot as plt
import sys

import amrs.vis
import smartcarb as sc

def satellite_field(time):
    fn = sc.io.create_filename(time, input_files='level2',
                               instrument='Sentinel_7_CO2', lon_eq=401,
                               orbit=1670)
    print(fn)

    data = sc.io.read_level2(fn, co2_noise=0.5, co2_thr=1.0)

    amrs.vis.make_level2_map(data.lonc, data.latc, data.CO2, clct=data.clouds,
                             vmin=402, vmax=410, label='XCO$_2$ (ppm)',
                             domain=sc.cfg.DOMAINS['smartcarb'])

    plt.savefig('level2_test.png')

def cosmo_field(time):

    # read XCO2 values
    fn = sc.io.create_filename(time, input_files='2D')
    rlon, rlat = sc.io.read_fields(fn, ['rlon', 'rlat'])
    values = sc.io.read_total_tracer(fn, 'CO2')
    print(fn)

    # make field map
    amrs.vis.make_field_map(rlon, rlat, values, vmin=402, vmax=410,
                            domain=sc.cfg.DOMAINS['smartcarb'],
                            label='XCO$_2$ (ppm)')

    plt.savefig('cosmo_test.png')


if __name__ == '__main__':
    time = datetime(2015,4,23,11)
    cosmo_field(time)
    satellite_field(time)




